/// <reference types="node" />
import { IStandardHeader } from './set/standard_header';
import { IApplicationSequenceControl } from './set/application_sequence_control';
import { IParties } from './set/parties';
import { IContraGrp } from './set/contra_grp';
import { IPreAllocGrp } from './set/pre_alloc_grp';
import { IInstrument } from './set/instrument';
import { IFinancingDetails } from './set/financing_details';
import { IUndInstrmtGrp } from './set/und_instrmt_grp';
import { IStipulations } from './set/stipulations';
import { IOrderQtyData } from './set/order_qty_data';
import { ITriggeringInstruction } from './set/triggering_instruction';
import { IPegInstructions } from './set/peg_instructions';
import { IDiscretionInstructions } from './set/discretion_instructions';
import { IStrategyParametersGrp } from './set/strategy_parameters_grp';
import { IFillsGrp } from './set/fills_grp';
import { ICommissionData } from './set/commission_data';
import { ISpreadOrBenchmarkCurveData } from './set/spread_or_benchmark_curve_data';
import { IYieldData } from './set/yield_data';
import { IDisplayInstruction } from './set/display_instruction';
import { IContAmtGrp } from './set/cont_amt_grp';
import { IInstrmtLegExecGrp } from './set/instrmt_leg_exec_grp';
import { IMiscFeesGrp } from './set/misc_fees_grp';
import { ITrdRegTimestamps } from './set/trd_reg_timestamps';
import { IStandardTrailer } from './set/standard_trailer';
import { IRateSource } from './set/rate_source';
export interface IExecutionReport {
    StandardHeader: IStandardHeader;
    ApplicationSequenceControl?: IApplicationSequenceControl;
    OrderID: string;
    SecondaryOrderID?: string;
    SecondaryClOrdID?: string;
    SecondaryExecID?: string;
    ClOrdID?: string;
    OrigClOrdID?: string;
    ClOrdLinkID?: string;
    QuoteRespID?: string;
    OrdStatusReqID?: string;
    MassStatusReqID?: string;
    HostCrossID?: string;
    TotNumReports?: number;
    LastRptRequested?: boolean;
    Parties?: IParties[];
    TradeOriginationDate?: Date;
    ContraGrp?: IContraGrp[];
    ListID?: string;
    CrossID?: string;
    OrigCrossID?: string;
    CrossType?: number;
    TrdMatchID?: string;
    ExecID: string;
    ExecRefID?: string;
    ExecType: string;
    OrdStatus: string;
    WorkingIndicator?: boolean;
    OrdRejReason?: number;
    ExecRestatementReason?: number;
    Account?: string;
    AcctIDSource?: number;
    AccountType?: number;
    DayBookingInst?: string;
    BookingUnit?: string;
    PreallocMethod?: string;
    AllocID?: string;
    PreAllocGrp?: IPreAllocGrp[];
    SettlType?: string;
    SettlDate?: Date;
    MatchType?: string;
    OrderCategory?: string;
    CashMargin?: string;
    ClearingFeeIndicator?: string;
    Instrument: IInstrument;
    FinancingDetails?: IFinancingDetails;
    UndInstrmtGrp?: IUndInstrmtGrp;
    Side: string;
    Stipulations?: IStipulations[];
    QtyType?: number;
    OrderQtyData?: IOrderQtyData;
    LotType?: string;
    OrdType?: string;
    PriceType?: number;
    Price?: number;
    PriceProtectionScope?: string;
    StopPx?: number;
    TriggeringInstruction?: ITriggeringInstruction;
    PegInstructions?: IPegInstructions;
    DiscretionInstructions?: IDiscretionInstructions;
    PeggedPrice?: number;
    PeggedRefPrice?: number;
    DiscretionPrice?: number;
    TargetStrategy?: number;
    StrategyParametersGrp?: IStrategyParametersGrp[];
    TargetStrategyParameters?: string;
    ParticipationRate?: number;
    TargetStrategyPerformance?: number;
    Currency?: string;
    ComplianceID?: string;
    SolicitedFlag?: boolean;
    TimeInForce?: string;
    EffectiveTime?: Date;
    ExpireDate?: Date;
    ExpireTime?: Date;
    ExecInst?: string;
    AggressorIndicator?: boolean;
    OrderCapacity?: string;
    OrderRestrictions?: string;
    PreTradeAnonymity?: boolean;
    CustOrderCapacity?: number;
    LastQty?: number;
    CalculatedCcyLastQty?: number;
    LastSwapPoints?: number;
    UnderlyingLastQty?: number;
    LastPx?: number;
    UnderlyingLastPx?: number;
    LastParPx?: number;
    LastSpotRate?: number;
    LastForwardPoints?: number;
    LastMkt?: string;
    TradingSessionID?: string;
    TradingSessionSubID?: string;
    TimeBracket?: string;
    LastCapacity?: string;
    LeavesQty: number;
    CumQty: number;
    AvgPx?: number;
    DayOrderQty?: number;
    DayCumQty?: number;
    DayAvgPx?: number;
    TotNoFills?: number;
    LastFragment?: boolean;
    FillsGrp?: IFillsGrp[];
    GTBookingInst?: number;
    TradeDate?: Date;
    TransactTime?: Date;
    ReportToExch?: boolean;
    CommissionData?: ICommissionData;
    SpreadOrBenchmarkCurveData?: ISpreadOrBenchmarkCurveData;
    YieldData?: IYieldData;
    GrossTradeAmt?: number;
    NumDaysInterest?: number;
    ExDate?: Date;
    AccruedInterestRate?: number;
    AccruedInterestAmt?: number;
    InterestAtMaturity?: number;
    EndAccruedInterestAmt?: number;
    StartCash?: number;
    EndCash?: number;
    TradedFlatSwitch?: boolean;
    BasisFeatureDate?: Date;
    BasisFeaturePrice?: number;
    Concession?: number;
    TotalTakedown?: number;
    NetMoney?: number;
    SettlCurrAmt?: number;
    SettlCurrency?: string;
    SettlCurrFxRate?: number;
    SettlCurrFxRateCalc?: string;
    HandlInst?: string;
    MinQty?: number;
    MatchIncrement?: number;
    MaxPriceLevels?: number;
    DisplayInstruction?: IDisplayInstruction;
    MaxFloor?: number;
    PositionEffect?: string;
    MaxShow?: number;
    BookingType?: number;
    Text?: string;
    EncodedTextLen?: number;
    EncodedText?: Buffer;
    SettlDate2?: Date;
    OrderQty2?: number;
    LastForwardPoints2?: number;
    MultiLegReportingType?: string;
    CancellationRights?: string;
    MoneyLaunderingStatus?: string;
    RegistID?: string;
    Designation?: string;
    TransBkdTime?: Date;
    ExecValuationPoint?: Date;
    ExecPriceType?: string;
    ExecPriceAdjustment?: number;
    PriorityIndicator?: number;
    PriceImprovement?: number;
    LastLiquidityInd?: number;
    ContAmtGrp?: IContAmtGrp[];
    InstrmtLegExecGrp?: IInstrmtLegExecGrp[];
    CopyMsgIndicator?: boolean;
    MiscFeesGrp?: IMiscFeesGrp[];
    DividendYield?: number;
    ManualOrderIndicator?: boolean;
    CustDirectedOrder?: boolean;
    ReceivedDeptID?: string;
    CustOrderHandlingInst?: string;
    OrderHandlingInstSource?: number;
    TrdRegTimestamps?: ITrdRegTimestamps[];
    Volatility?: number;
    TimeToExpiration?: number;
    RiskFreeRate?: number;
    PriceDelta?: number;
    StandardTrailer: IStandardTrailer;
    RateSource?: IRateSource[];
}
